<?php

namespace FiloBlu\Refilo\Model\Indexer;

use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\StoreManagerInterface;

class Config
{
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var Mongo
     */
    private $mongo;

    public function __construct(
        StoreManagerInterface $storeManager,
        ScopeConfigInterface $scopeConfig,
        Mongo $mongo
    ) {
        $this->storeManager = $storeManager;
        $this->scopeConfig = $scopeConfig;
        $this->mongo = $mongo;
    }

    public function exportConfig()
    {
        $stores = $this->storeManager->getStores();
        $bulkData = [];
        foreach ($stores as $key => $value) {
            $store_code = $value->getData('code');

            $config = $this->scopeConfig->getValue("", \Magento\Store\Model\ScopeInterface::SCOPE_STORE, $store_code);

            $store_data = new \stdClass();
            $store_data->metacode = "store";
            $store_data->_id = "country_" . (string)$store_code;

            $metadata = new \stdClass();
            $metadata->name = $value->getName();
            $metadata->code = $value->getCode();
            $metadata->isoCode = $value->getCode();
            $metadata->marketplace = $value->getWebsite()->getCode();

            $metadata->locale = (object) $config['general']["locale"];
            $metadata->locale->name = $metadata->locale->code;

            $currency = new \stdClass();
            $currency->code = $config["currency"]["options"]["default"];
            $metadata->currencies[] = $currency;

            $metadata->configs = new \stdClass();
            $metadata->configs->default_currency = $config["currency"]["options"]["default"];
            $metadata->configs->store_information = array_key_exists("store_information", $config["general"]) ? (object) $config["general"]["store_information"] : '';
            $metadata->configs->billing_countries = explode(",", $config["general"]["country"]["allow"]);
            $metadata->configs->shipping_countries = array_key_exists("allow_shipping", $config["general"]["country"]) ? explode(",", $config["general"]["country"]["allow_shipping"]) : '';

            if (isset($config["geolocation"]["country_store"]["affected_countries"])) {
                $metadata->configs->navigation_countries = explode(",", $config["geolocation"]["country_store"]["affected_countries"]);
            }

            $metadata->configs->europe_countries = explode(",", $config["general"]["country"]["eu_countries"]);
            $metadata->configs->default_country = $config["general"]["country"]["default"];

            $metadata->storefrontConfig = new \stdClass();
            $metadata->storefrontConfig->catalog = new \stdClass();

            $metadata->storefrontConfig->catalog->show_out_of_stock = $config["cataloginventory"]["options"]["show_out_of_stock"];
            $metadata->storefrontConfig->catalog->root_category_id = $config["catalog"]["category"]["root_id"];
            $metadata->storefrontConfig->catalog->frontend = (object) $config["catalog"]["frontend"];

            $store_data->metadata = $metadata;
            $bulkData[] = $store_data;
        }
        $this->mongo->update(
            '_id',
            $bulkData,
            'configs',
            true,
            $this->scopeConfig->getValue('mongo/general/mongo_general_database')
        );
    }
}
